<?xml version="1.0" encoding="UTF-8"?>
<!-- 
 * ToFeed - Non-intrusive RSS feed generator for MediaWiki articles.
 * Copyright (C) 2009 Sylvain Leroux - sylvain@chicoree.fr
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
-->
<xsl:stylesheet version="1.0" 
				xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
				xmlns:php="http://php.net/xsl"
				xmlns:atom="http://www.w3.org/2005/Atom">
    <xsl:variable name="baseURL" select="/html/head/base/@href" />
    <xsl:output cdata-section-elements="description" />
    
	<xsl:template match="/">
        <rss version="2.0">
            <channel>
                <title><xsl:value-of select="/html/head/title" /></title>
                <link><xsl:value-of select="$baseURL" /></link>
                <atom:link href="{$baseURL}?action=toFeed" rel="self" type="application/rss+xml">
                </atom:link>
                <xsl:apply-templates select="/html/body" mode="page-description" />
                <!-- Apply template to the first list (usually the TOC) -->
                <xsl:apply-templates select="(descendant::ol|descendant::ul)[1]" />
                <!-- Apply template to the first ''explicitly'' included list -->
                <xsl:apply-templates select="(descendant::ol|descendant::ul)[@class='xxxx'][1]" />
            </channel>
        </rss>
	</xsl:template>
    <xsl:template match="ul|ol">
        <xsl:for-each select=".//li">
            <item>
                <xsl:apply-templates select="." />
            </item>
        </xsl:for-each>
    </xsl:template>
    <xsl:template match="li[descendant::a/@href]">
        <title><xsl:value-of select="descendant::a[@href][1]" /></title>
        <link><xsl:value-of select="php:function('tfResolveFullURL',string($baseURL),string(a[@href][1]/@href))" /></link>
        <description>
            <xsl:apply-templates select="descendant::a[@href][1]" mode="link-description"/>
        </description>
    </xsl:template>
    
    <xsl:template match="*" mode="link-description">
        <!-- The first paragraph of the corresponding section if there is one -->
        <xsl:variable name="anchor" select="@href" />
        <xsl:apply-templates select="//a[concat('#',@name)=$anchor]/following-sibling::p[1]" mode="embed" />
    </xsl:template>
    
    <xsl:template match="*" mode="page-description">
        <!-- The description is any paragraph before the first list/heading -->
        <description>
            <xsl:for-each select="(descendant::ol|descendant::ul|descendant::h1|descendant::h2)[1]/preceding::p[parent::body]">
                <xsl:for-each select="descendant-or-self::*/text()">
                    <xsl:copy />
                </xsl:for-each>
            </xsl:for-each>
        </description>
    </xsl:template>
    
    <xsl:template match="*" mode="embed">
        <![CDATA[<]]><xsl:value-of select="name()"/><![CDATA[>]]>
        <xsl:apply-templates select="*|text()" mode="embed"/>
        <![CDATA[</]]><xsl:value-of select="name()"/><![CDATA[>]]>
    </xsl:template>
    <xsl:template match="text()" mode="embed">
        <xsl:copy />
    </xsl:template>
    
</xsl:stylesheet>