<?php

$IP = '../..';
$SIMPLETEST_HOME = '/usr/local/lib/simpletest';
require_once($SIMPLETEST_HOME . '/autorun.php');

require_once("$IP/extensions/ToFeed/ToFeed.php");

class MockFeed {
	static $theFeed;
	
	function __construct($title, $description, $url) {
		MockFeed::$theFeed = $this;
		
        $this->title = $title;
        $this->description = $description;
        $this->url = $url;
        $this->items = array();
	}
	
	function outFooter() {
		// do nothing
	}
	
	function outHeader() {
		// do nothing
	}
	
	function outItem($item) {
		$this->items[] = $item;
	}
}

class UtilTestCase extends UnitTestCase {
    function UtilTestCase() {
    	$this->UnitTestCase('ToFeed utilities test');
    }	

	/**
	 * Test resolveFullURL against several use case
	 */
    function testURLBuilder() {
    	$testCases = array(
    	/* RELATIVE URLs */
            array("http://www.chicoree.fr/Accueil", "Derby", "http://www.chicoree.fr/Derby"),
            array("http://www.chicoree.fr/", "Derby", "http://www.chicoree.fr/Derby"),
            array("http://www.chicoree.fr", "Derby", "http://www.chicoree.fr/Derby"),
            array("http://www.chicoree.fr/w/Accueil", "Derby", "http://www.chicoree.fr/w/Derby"),
            array("http://www.chicoree.fr/w/", "Derby", "http://www.chicoree.fr/w/Derby"),
        /* ABSOLUTE URLs */
            array("http://www.chicoree.fr", "/Accueil", "http://www.chicoree.fr/Accueil"),
            array("http://www.chicoree.fr/", "/Accueil", "http://www.chicoree.fr/Accueil"),
            array("http://www.chicoree.fr/w/Derby", "/Accueil", "http://www.chicoree.fr/Accueil"),
        /* FULL URLs */
            array("http://www.chicoree.fr", "http://www.mediawiki.org", "http://www.mediawiki.org"),
            array("http://www.chicoree.fr/w/Accueil", "http://www.mediawiki.org", "http://www.mediawiki.org"),
        /* FRAGMENTS */
            array("http://www.chicoree.fr/Accueil", "#top", "http://www.chicoree.fr/Accueil#top")
        
        );
    	
    	foreach ($testCases as $case) {
    		$this->assertEqual(resolveFullURL($case[0], $case[1]), $case[2]);
    	}
    }
    
    function testValidHtmlDocumentToFeed() {
    	$title = "My document";
    	$url = "http://www.chicoree.fr/w/My_document";
    	$description = array(
    	   "This is a document that explains ",
    	   "this",
    	   " and ",
    	   "that",
    	   ".",
    	   "This is the ",
    	   "second",
    	   " paragraph."
    	);
        $html =<<< EOF
                <html>
                    <head>
                        <title>$title</title>
                        <base href="$url" />
                        <meta http-equiv='content-type' content='text/html; charset=UTF-8'>
                    </head>
                    <body>
                        <div>$description[0]<i>$description[1]</i>$description[2]<em>$description[3]</em>$description[4]</div>
                        <p>$description[5]<i>$description[6]</i>$description[7]</p>
                        <ol>
                            <li>Some <a href='http://www.chicoree.fr/Page'>page</a> here</li>
                            <li>An <a href='http://www.chicoree.fr/Other'><i>other</i> page</a> here
                                <ul>
                                    <li>A <a href='#top'>fragment</a> here</li>
                                </ul>
                            </li>
                        </ol>
                        <p>An other paragraph</p>
                        <ol>
                            <li>Unused item list</li>
                        </ol>
                    </body>
                </html>
EOF;
        htmlDocumentToFeed($html, "MockFeed");
        $this->assertEqual($title, MockFeed::$theFeed->title);
        $this->assertEqual($url, MockFeed::$theFeed->url);
        $this->assertEqual(join("", $description), MockFeed::$theFeed->description);
        
        $this->assertEqual(3, count(MockFeed::$theFeed->items));
        $this->assertEqual("Some page here", MockFeed::$theFeed->items[0]->Description);
        $this->assertEqual("page", MockFeed::$theFeed->items[0]->Title);
        $this->assertEqual("http://www.chicoree.fr/Page", MockFeed::$theFeed->items[0]->Url);
        
        $this->assertEqual("An other page here", MockFeed::$theFeed->items[1]->Description);
        $this->assertEqual("other page", MockFeed::$theFeed->items[1]->Title);
        $this->assertEqual("http://www.chicoree.fr/Other", MockFeed::$theFeed->items[1]->Url);
        
        $this->assertEqual("A fragment here", MockFeed::$theFeed->items[2]->Description);
        $this->assertEqual("fragment", MockFeed::$theFeed->items[2]->Title);
        $this->assertEqual("$url#top", MockFeed::$theFeed->items[2]->Url);
    }
    /*
    function testInvalidHtmlDocumentToFeed() {
        $title = "My document";
        $url = "http://www.chicoree.fr/w/My_document";
        $description = array(
           "This is a document that explains ",
           "this",
           " and ",
           "that",
           ".",
           "This is the ",
           "second",
           " paragraph."
        );
        $html =<<< EOF
                html><!-- Malformed open tag !!! -->
                    <head>
                        <title>$title</title>
                        <base href="$url" />
                        <meta http-equiv='content-type' content='text/html; charset=UTF-8'>
                    </head>
                    <body>
                        <div>$description[0]<i>$description[1]</i>$description[2]<em>$description[3]</em>$description[4]</div>
                        <p>$description[5]<i>$description[6]</i>$description[7]</p>
                        <ol>
                            <li>Some <a href='http://www.chicoree.fr/Page'>page</a> here</li>
                            <li>An <a href='http://www.chicoree.fr/Other'><i>other</i> page</a> here
                                <ul>
                                    <li>A <a href='#top'>fragment</a> here</li>
                                </ul>
                            </li>
                        </ol>
                    </body>
                </html>
EOF;
        htmlDocumentToFeed($html, "MockFeed");
        $this->assertEqual("No title", MockFeed::$theFeed->title);
        $this->assertEqual("No url", MockFeed::$theFeed->url);
    }
    */
}
